==> camel-k-model-v1-5.3.0-sources.jar: io/fabric8/camelk/v1/IntegrationKitSpecBuilder.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class IntegrationKitSpecBuilder extends IntegrationKitSpecFluentImpl<IntegrationKitSpecBuilder> implements VisitableBuilder<IntegrationKitSpec,IntegrationKitSpecBuilder> {

    IntegrationKitSpecFluent<?> fluent;
    Boolean validationEnabled;

    public IntegrationKitSpecBuilder() {
        this(true);
    }

    public IntegrationKitSpecBuilder(Boolean validationEnabled) {
        this(new IntegrationKitSpec(), validationEnabled);
    }

    public IntegrationKitSpecBuilder(IntegrationKitSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public IntegrationKitSpecBuilder(IntegrationKitSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new IntegrationKitSpec(), validationEnabled);
    }

    public IntegrationKitSpecBuilder(IntegrationKitSpecFluent<?> fluent,IntegrationKitSpec instance) {
        this(fluent, instance, true);
    }

    public IntegrationKitSpecBuilder(IntegrationKitSpecFluent<?> fluent,IntegrationKitSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withConfiguration(instance.getConfiguration()); 
        fluent.withDependencies(instance.getDependencies()); 
        fluent.withImage(instance.getImage()); 
        fluent.withProfile(instance.getProfile()); 
        fluent.withRepositories(instance.getRepositories()); 
        fluent.withTraits(instance.getTraits()); 
        this.validationEnabled = validationEnabled; 
    }

    public IntegrationKitSpecBuilder(IntegrationKitSpec instance) {
        this(instance,true);
    }

    public IntegrationKitSpecBuilder(IntegrationKitSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withConfiguration(instance.getConfiguration()); 
        this.withDependencies(instance.getDependencies()); 
        this.withImage(instance.getImage()); 
        this.withProfile(instance.getProfile()); 
        this.withRepositories(instance.getRepositories()); 
        this.withTraits(instance.getTraits()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.camelk.v1.EditableIntegrationKitSpec build() {
        EditableIntegrationKitSpec buildable = new EditableIntegrationKitSpec(fluent.getConfiguration(),fluent.getDependencies(),fluent.getImage(),fluent.getProfile(),fluent.getRepositories(),fluent.getTraits());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        IntegrationKitSpecBuilder that = (IntegrationKitSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> camel-k-model-v1-5.4.2-sources.jar: io/fabric8/camelk/v1/IntegrationKitSpecBuilder.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class IntegrationKitSpecBuilder extends io.fabric8.camelk.v1.IntegrationKitSpecFluentImpl<io.fabric8.camelk.v1.IntegrationKitSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.camelk.v1.IntegrationKitSpec,io.fabric8.camelk.v1.IntegrationKitSpecBuilder> {

    io.fabric8.camelk.v1.IntegrationKitSpecFluent<?> fluent;
    java.lang.Boolean validationEnabled;

    public IntegrationKitSpecBuilder() {
        this(true);
    }

    public IntegrationKitSpecBuilder(java.lang.Boolean validationEnabled) {
        this(new IntegrationKitSpec(), validationEnabled);
    }

    public IntegrationKitSpecBuilder(io.fabric8.camelk.v1.IntegrationKitSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public IntegrationKitSpecBuilder(io.fabric8.camelk.v1.IntegrationKitSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
        this(fluent, new IntegrationKitSpec(), validationEnabled);
    }

    public IntegrationKitSpecBuilder(io.fabric8.camelk.v1.IntegrationKitSpecFluent<?> fluent,io.fabric8.camelk.v1.IntegrationKitSpec instance) {
        this(fluent, instance, true);
    }

    public IntegrationKitSpecBuilder(io.fabric8.camelk.v1.IntegrationKitSpecFluent<?> fluent,io.fabric8.camelk.v1.IntegrationKitSpec instance,java.lang.Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withConfiguration(instance.getConfiguration()); 
        fluent.withDependencies(instance.getDependencies()); 
        fluent.withImage(instance.getImage()); 
        fluent.withProfile(instance.getProfile()); 
        fluent.withRepositories(instance.getRepositories()); 
        fluent.withTraits(instance.getTraits()); 
        this.validationEnabled = validationEnabled; 
    }

    public IntegrationKitSpecBuilder(io.fabric8.camelk.v1.IntegrationKitSpec instance) {
        this(instance,true);
    }

    public IntegrationKitSpecBuilder(io.fabric8.camelk.v1.IntegrationKitSpec instance,java.lang.Boolean validationEnabled) {
        this.fluent = this; 
        this.withConfiguration(instance.getConfiguration()); 
        this.withDependencies(instance.getDependencies()); 
        this.withImage(instance.getImage()); 
        this.withProfile(instance.getProfile()); 
        this.withRepositories(instance.getRepositories()); 
        this.withTraits(instance.getTraits()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.camelk.v1.EditableIntegrationKitSpec build() {
        EditableIntegrationKitSpec buildable = new EditableIntegrationKitSpec(fluent.getConfiguration(),fluent.getDependencies(),fluent.getImage(),fluent.getProfile(),fluent.getRepositories(),fluent.getTraits());
        return buildable;
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        IntegrationKitSpecBuilder that = (IntegrationKitSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
